<?php

namespace Drupal\fundraise_up_api\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class ConfigForm.
 *
 * @package Drupal\fundraise_up_api\Form
 */
class ConfigForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory')
    );
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'fundraise_up_api.config',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'fundraise_up_api_config_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('fundraise_up_api.config');

    // Settings for Open API.
    $form['rest_api'] = [
      '#type' => 'fieldset',
      '#collapsible' => FALSE,
      '#title' => $this->t('Rest API'),
      '#tree' => TRUE,
    ];
    $form['rest_api']['enabled'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enabled'),
      '#default_value' => $config->get('rest_api.enabled'),
    ];
    $form['rest_api']['api_key_live'] = [
      '#type' => 'textfield',
      '#title' => $this->t('API Key Live'),
      '#description' => $this->t('API Key used for authentication to connect to Live Rest API.'),
      '#maxlength' => 255,
      '#size' => 255,
      '#default_value' => $config->get('rest_api.api_key_live'),
    ];
    $form['rest_api']['api_key_test'] = [
      '#type' => 'textfield',
      '#title' => $this->t('API Key Test'),
      '#description' => $this->t('API Key used for authentication to connect to Test Rest API.'),
      '#maxlength' => 255,
      '#size' => 255,
      '#default_value' => $config->get('rest_api.api_key_test'),
    ];
    $form['rest_api']['timeout'] = [
      '#type' => 'number',
      '#title' => $this->t('Timeout'),
      '#description' => $this->t('Timeout (in seconds) for API requests. Put "0" for no timeout.'),
      '#maxlength' => 3,
      '#default_value' => $config->get('rest_api.timeout') ?? 60,
    ];

    $form['debug'] = [
      '#type' => 'fieldset',
      '#collapsible' => FALSE,
      '#title' => $this->t('Debug settings'),
      '#tree' => TRUE,
    ];
    $form['debug']['verbose'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Verbose logging'),
      '#default_value' => $config->get('debug.verbose'),
    ];
    $form['debug']['test_mode'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Test mode'),
      '#default_value' => $config->get('debug.test_mode'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    $rest_api = $form_state->getValue('rest_api');
    $debugConfig = $form_state->getValue('debug');
    if (empty($debugConfig['test_mode']) && empty($rest_api['api_key_live'])) {
      $form_state->setError($form['rest_api']['api_key_live'], 'API Key Live is required when Test mode is disabled.');
    }

    if (!empty($debugConfig['test_mode']) && empty($rest_api['api_key_test'])) {
      $form_state->setError($form['rest_api']['api_key_test'], 'API Key Test is required when Test mode is enabled.');
    }

    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    $this->config('fundraise_up_api.config')
      ->set('rest_api', $form_state->getValue('rest_api'))
      ->set('debug', $form_state->getValue('debug'))
      ->save();
  }

}
