<?php

namespace Drupal\fundraise_up_api\Form\Donations;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class GetDonationByIdForm.
 *
 * @package Drupal\fundraise_up_api\Form\Donations
 */
class GetDonationByIdForm extends FormBase {

  /**
   * Rest Api client.
   *
   * @var \Drupal\fundraise_up_api\Http\RestApiClient
   */
  protected $restApiClient;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    $instance = parent::create($container);
    $instance->restApiClient = $container
      ->get('fundraise_up_api.manager')
      ->getRestApiClient();

    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'fundraise_up_api_get_donation_by_id_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['fieldset'] = [
      '#type' => 'fieldset',
      '#collapsible' => FALSE,
      '#title' => $this->t('Retrieve the donation data by ID'),
      '#tree' => FALSE,
    ];

    if (!$this->restApiClient) {
      $form['fieldset']['error'] = [
        '#type' => 'markup',
        '#markup' => $this->t('Configure Fundraise Up API module before making requests.'),
      ];

      return $form;
    }

    $result = $form_state->get('result');

    if ($result) {
      $form['fieldset']['result'] = [
        '#type' => 'textarea',
        '#title' => $this->t('The result'),
        '#disabled' => TRUE,
        '#rows' => 20,
        '#default_value' => print_r($result, TRUE),
      ];
    }

    $form['fieldset']['donation_by_id_id'] = [
      '#type' => 'textfield',
      '#required' => TRUE,
      '#title' => $this->t('Donation ID'),
      '#description' => $this->t('Find the "Donation ID" on <a href="@dashboard-link" target="_blank">Donations list page</a>.', [
        '@dashboard-link' => 'https://dashboard.fundraiseup.com/',
      ]),
    ];

    $form['fieldset']['actions']['#type'] = 'actions';

    $form['fieldset']['actions']['submit_donation_by_id'] = [
      '#type' => 'submit',
      '#value' => $this->t('Submit'),
      '#button_type' => 'primary',
    ];

    // Prevents cache-serialize exceptions.
    // The problem can be investigated later.
    $form_state->disableCache();

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $donations = $this->restApiClient->donations();

    $id = $form_state->getValue('donation_by_id_id');

    try {
      $response = $donations->getDonationsById($id);
      $form_state->set('result', $response->getData());
    }
    catch (\Throwable $e) {
      if ($e->getCode() === 400) {
        $this->messenger()->addError($this->t('Unable to retrieve donation details for "@id".', ['@id' => $id]));
      }
      else {
        $this->messenger()->addError($e->getMessage());
      }
    }

    $form_state->setRebuild();
  }

}
