<?php

namespace Drupal\fundraise_up_api\Form\Donations;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class GetDonationsForm.
 *
 * @package Drupal\fundraise_up_api\Form\Donations
 */
class GetDonationsForm extends FormBase {

  /**
   * Rest Api client.
   *
   * @var \Drupal\fundraise_up_api\Http\RestApiClient
   */
  protected $restApiClient;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    $instance = parent::create($container);
    $instance->restApiClient = $container
      ->get('fundraise_up_api.manager')
      ->getRestApiClient();

    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'fundraise_up_api_get_donations_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['fieldset'] = [
      '#type' => 'fieldset',
      '#collapsible' => FALSE,
      '#title' => $this->t('Retrieve all donations'),
      '#tree' => FALSE,
    ];

    if (!$this->restApiClient) {
      $form['fieldset']['error'] = [
        '#type' => 'markup',
        '#markup' => $this->t('Configure Fundraise Up API module before making requests.'),
      ];

      return $form;
    }

    $result = $form_state->get('result');

    if ($result) {
      $form['fieldset']['result'] = [
        '#type' => 'textarea',
        '#title' => $this->t('The result'),
        '#disabled' => TRUE,
        '#rows' => 20,
        '#default_value' => print_r($result, TRUE),
      ];
    }

    $form['fieldset']['donations_records'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Number of records'),
      '#required' => TRUE,
      '#default_value' => 10,
      '#description' => $this->t('Specify the number of records per page, ranging from 1 to 100.'),
    ];

    $form['fieldset']['donations_ending_before'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Ending before'),
      '#description' => $this->t('Use an existing object ID to define your position in the list. For example, if you fetch a list of items and receive 100 results, you can use the ID of the first object in that list as the ending_before parameter in your subsequent request to retrieve the previous page of results.'),
    ];
    $form['fieldset']['donations_starting_after'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Starting after'),
      '#description' => $this->t('Use an existing object ID to define your position in the list. For example, if you fetch a list of items and receive 100 results, you can use the ID of the last object in that list as the starting_after parameter in your subsequent request to retrieve the next page of results.'),
    ];

    $form['fieldset']['actions']['#type'] = 'actions';

    $form['fieldset']['actions']['submit_donations'] = [
      '#type' => 'submit',
      '#value' => $this->t('Submit'),
      '#button_type' => 'primary',
    ];

    // Prevents cache-serialize exception.
    // The problem can be investigated later.
    $form_state->disableCache();

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $donations = $this->restApiClient->donations();

    $records = $form_state->getValue('donations_records');
    $endingBefore = $form_state->getValue('donations_ending_before');
    $startingAfter = $form_state->getValue('donations_starting_after');

    try {
      $response = $donations->getDonations($records, $endingBefore, $startingAfter);
      $form_state->set('result', $response->getData());
    }
    catch (\Throwable $e) {
      $this->messenger()->addError($e->getMessage());
    }

    $form_state->setRebuild();
  }

}
