<?php

namespace Drupal\fundraise_up_api\Http;

use Psr\Log\LoggerInterface;

/**
 * Class RestApiClient.
 *
 * Provides REST Api resources
 * @see https://fundraiseup.com/docs/rest-api-resources/
 *
 * @method \Drupal\fundraise_up_api\Resources\RestApi\Donations donations()
 * @method \Drupal\fundraise_up_api\Resources\RestApi\Events events()
 * @method \Drupal\fundraise_up_api\Resources\RestApi\RecurringPlans recurringPlans()
 * @method \Drupal\fundraise_up_api\Resources\RestApi\Supporters supporters()
 */
class RestApiClient extends Client {

  /**
   * {@inheritdoc}
   */
  public function __construct(LoggerInterface $logger, $config = [], $clientOptions = []) {
    if (empty($config['api_key'])) {
      $message = t('You must provide Fundraise Up API key.');
      \Drupal::logger('fundraise_up_api')->error($message);
      throw new \Exception($message);
    }
    // Attaches secret code to each request.
    $clientOptions['headers']['Authorization'] = 'Bearer ' . $config['api_key'];

    parent::__construct($logger, $config, $clientOptions);
  }

  /**
   * Return an instance of a Resource based on the method called.
   *
   * @param string $name
   *   Name of the method.
   * @param array $arguments
   *   Arguments that will be passed further.
   *
   * @return \Drupal\fundraise_up_api\Resources\Resource
   *   Resource object.
   */
  public function __call($name, array $arguments = NULL) {
    $resource = 'Drupal\\fundraise_up_api\\Resources\\RestApi\\' . ucfirst($name);

    return new $resource($this);
  }

}
