<?php

namespace Drupal\fundraise_up_api;

use Drupal\fundraise_up_api\Http\RestApiClient;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Logger\LoggerChannelFactoryInterface;

/**
 * Fundraise Up API Manager.
 */
class Manager implements ManagerInterface {

  /**
   * The config for Fundraise Up API.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $config;

  /**
   * Logger service.
   *
   * @var \Psr\Log\LoggerInterface
   */
  protected $logger;

  /**
   * Constructs a new Fundraise Up API service instance.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   * @param \Drupal\Core\Logger\LoggerChannelFactoryInterface $logger_factory
   *   The logger factory.
   */
  public function __construct(ConfigFactoryInterface $config_factory, LoggerChannelFactoryInterface $logger_factory) {
    $this->config = $config_factory->get('fundraise_up_api.config');
    $this->logger = $logger_factory->get('fundraise_up_api');
  }

  /**
   * {@inheritdoc}
   */
  public function getRestApiClient() {
    $rest_api_config = $this->config->get('rest_api');
    $debug_config = $this->config->get('debug');

    if (!$rest_api_config['enabled']) {
      $this->logger->info('Fundraise Up API is disabled.');
      return NULL;
    }

    $config = [
      'api_key' => $debug_config['test_mode'] ? $rest_api_config['api_key_test'] : $rest_api_config['api_key_live'],
      'debug' => $debug_config,
    ];

    if (empty($config['api_key'])) {
      $this->logger->error('Missing Fundraise Up API Key configuration.');
      return NULL;
    }

    $client_options = [];
    if (!empty($rest_api_config['timeout'])) {
      $client_options['timeout'] = $rest_api_config['timeout'];
    }

    return new RestApiClient($this->logger, $config, $client_options);
  }

}
