<?php

namespace Drupal\fundraise_up_api\Resources\RestApi;

use Drupal\fundraise_up_api\Resources\Resource;
use GuzzleHttp\Utils;

/**
 * Donations class.
 */
class Donations extends Resource {

  /**
   * Retrieves details of the Donations records.
   *
   * @param int $limit
   *   Specifies the number of records per page, ranging from 1 to 100.
   * @param string $endingBefore
   *    Uses an existing object ID to define your position in the list.
   * @param string $startingAfter
   *   Uses an existing object ID to define your position in the list.
   *
   * @return \Drupal\fundraise_up_api\Http\Response
   *   Response object containing Donations data.
   */
  public function getDonations($limit = 100, $endingBefore = NULL, $startingAfter = NULL ) {
    $qs = [
      'limit' => $limit,
    ];

    if ($endingBefore) {
      $qs['ending_before'] = $endingBefore;
    }
    if ($startingAfter) {
      $qs['starting_after'] = $startingAfter;
    }

    $endpoint = "/v1/donations?" . http_build_query($qs);

    return $this->client->request('get', $endpoint);
  }

  /**
   * Retrieves details of the Donation record associated with the supplied id.
   *
   * @param string $donation_id
   *   Unique identifier for the donation.
   *
   * @return \Drupal\fundraise_up_api\Http\Response
   *   Response object containing the donation object.
   */
  public function getDonationsById($donation_id) {
    $endpoint = "/v1/donations/$donation_id";

    return $this->client->request('get', $endpoint);
  }

  /**
   * Create Donation.
   *
   * @param object $data
   *   Donation data object.
   *
   * @return \Drupal\fundraise_up_api\Http\Response
   *   Response object.
   */
  public function createDonation($data) {
    $endpoint = '/v1/donations';

    return $this->client->request('post', $endpoint, ['body' => Utils::jsonEncode($data)]);
  }

  /**
   * Update Donation.
   *
   * @param int $donation_id
   *   Unique identifier for the Donation.
   * @param object $data
   *   Donation data object.
   *
   * @return \Drupal\fundraise_up_api\Http\Response
   *   Response object.
   */
  public function updateDonation($donation_id, $data) {
    $endpoint = "/v1/donations/$donation_id";

    return $this->client->request('post', $endpoint, ['body' => Utils::jsonEncode($data)]);
  }

}
