<?php

namespace Drupal\fundraise_up_api\Resources\RestApi;

use Drupal\fundraise_up_api\Resources\Resource;

/**
 * Events class.
 */
class Events extends Resource {

  /**
   * Retrieves details of the Event records.
   *
   * @param array $types
   *   An array of up to 10 strings containing specific event types.
   * @param int $limit
   *   Specifies the number of records per page, ranging from 1 to 100.
   * @param string $endingBefore
   *   Uses an existing object ID to define your position in the list.
   * @param string $startingAfter
   *   Uses an existing object ID to define your position in the list.
   *
   * @return \Drupal\fundraise_up_api\Http\Response
   *   Response object containing Events data.
   */
  public function getEvents($types, $limit = 100, $endingBefore = NULL, $startingAfter = NULL) {
    $qs = [
      'types' => $types,
      'limit' => $limit,
    ];

    if ($endingBefore) {
      $qs['ending_before'] = $endingBefore;
    }
    if ($startingAfter) {
      $qs['starting_after'] = $startingAfter;
    }

    $endpoint = "/v1/events?" . preg_replace('/(%5B)\d+(%5D=)/i', '=', http_build_query($qs));

    return $this->client->request('get', $endpoint);
  }

}
