<?php

namespace Drupal\fundraise_up_api\Resources\RestApi;

use Drupal\fundraise_up_api\Resources\Resource;

/**
 * RecurringPlans class.
 */
class RecurringPlans extends Resource {

  /**
   * Retrieves details of the Recurring plans records.
   *
   * @param int $limit
   *   Specifies the number of records per page, ranging from 1 to 100.
   * @param string $endingBefore
   *    Uses an existing object ID to define your position in the list.
   * @param string $startingAfter
   *   Uses an existing object ID to define your position in the list.
   *
   * @return \Drupal\fundraise_up_api\Http\Response
   *   Response object containing Recurring plans data.
   */
  public function getRecurringPlans($limit = 100, $endingBefore = NULL, $startingAfter = NULL) {
    $qs = [
      'limit' => $limit,
    ];

    if ($endingBefore) {
      $qs['ending_before'] = $endingBefore;
    }
    if ($startingAfter) {
      $qs['starting_after'] = $startingAfter;
    }

    $endpoint = "/v1/recurring_plans?" . http_build_query($qs);

    return $this->client->request('get', $endpoint);
  }

  /**
   * Retrieves details of the Recurring plan associated with the supplied id.
   *
   * @param string $recurring_plan_id
   *   Unique identifier for the Recurring plan record.
   *
   * @return \Drupal\fundraise_up_api\Http\Response
   *   Response object containing the Recurring plan object.
   */
  public function getRecurringPlanById($recurring_plan_id) {
    $endpoint = "/v1/recurring_plans/$recurring_plan_id";

    return $this->client->request('get', $endpoint);
  }

}
