<?php

namespace Drupal\fundraise_up_api\Resources\RestApi;

use Drupal\fundraise_up_api\Resources\Resource;

/**
 * Supporters class.
 */
class Supporters extends Resource {

  /**
   * Retrieves details of the Supporter records.
   *
   * @param int $limit
   *   Specifies the number of records per page, ranging from 1 to 100.
   * @param string $endingBefore
   *   Uses an existing object ID to define your position in the list.
   * @param string $startingAfter
   *   Uses an existing object ID to define your position in the list.
   *
   * @return \Drupal\fundraise_up_api\Http\Response
   *   Response object containing Supporters data.
   */
  public function getSupporters($limit = 100, $endingBefore = NULL, $startingAfter = NULL) {
    $qs = [
      'limit' => $limit,
    ];

    if ($endingBefore) {
      $qs['ending_before'] = $endingBefore;
    }
    if ($startingAfter) {
      $qs['starting_after'] = $startingAfter;
    }

    $endpoint = "/v1/supporters?" . http_build_query($qs);

    return $this->client->request('get', $endpoint);
  }

  /**
   * Retrieves details of the Supporter record associated with the supplied id.
   *
   * @param string $supporter_id
   *   Unique identifier for the Supporter.
   *
   * @return \Drupal\fundraise_up_api\Http\Response
   *   Response object containing the Supporter object.
   */
  public function getSupporterById($supporter_id) {
    $endpoint = "/v1/supporters/$supporter_id";

    return $this->client->request('get', $endpoint);
  }

}
